@@ -47,7 +47,7 @@ class NacosService(metaclass=SingletonMeta):
             self.retry_backoff = self.nacos_config.get('retryBackoff', 1.5)
             self.max_retry_delay = self.nacos_config.get('maxRetryDelay', 30)
             self.heartbeat_interval = self.nacos_config.get(
-                'heartbeatInterval', 10)
+                'heartbeatInterval', 15)
             self.register_retry_interval = self.nacos_config.get(
                 'registerRetryInterval', 5)  # 注册重试间隔
 
@@ -87,12 +87,18 @@ class NacosService(metaclass=SingletonMeta):
             # 心跳相关
             self._last_heartbeat_time = 0
             self._heartbeat_fail_count = 0
-            self._heartbeat_lock = threading.Lock()  # 控制心跳线程创建的锁
+            self._heartbeat_lock = threading.Lock()
             self._heartbeat_thread = None
 
             self.max_heartbeat_timeout = self.nacos_config.get(
-                'maxHeartbeatTimeout', 30)  # 最大无心跳时间(秒)
-            self._last_successful_heartbeat = time.time()  # 上次成功心跳时间戳
+                'maxHeartbeatTimeout', 30)
+            self._last_successful_heartbeat = time.time()
+            # 连接监控检查间隔（新增配置，默认30秒，避免硬编码）
+            self.connection_check_interval = self.nacos_config.get(
+                'connectionCheckInterval', 30)
+            # 配置监视线程检查间隔（默认30秒）
+            self.config_watch_interval = self.nacos_config.get(
+                'configWatchInterval', 30)
 
             # 启动配置监视线程
             self._watch_thread = threading.Thread(
@@ -586,10 +592,9 @@ class NacosService(metaclass=SingletonMeta):
 
     def monitor_connection(self):
         """优化的连接监控线程，缩短检查间隔"""
-        # 缩短检查间隔（5秒一次）
-        check_interval = self.nacos_config.get('checkInterval', 5)
-        thread_start_time = time.time()  # 线程启动时间
-        check_counter = 0  # 检查计数器
+        check_interval = self.connection_check_interval
+        thread_start_time = time.time()
+        check_counter = 0
 
         while not self._shutdown_event.is_set():
             try:
@@ -739,7 +744,7 @@ class NacosService(metaclass=SingletonMeta):
 
     def _watch_configs(self):
         """配置监听线程"""
-        check_interval = 5  # 固定检查间隔
+        check_interval = self.config_watch_interval
 
         while not self._shutdown_event.is_set():
             try:
@@ -750,7 +755,7 @@ class NacosService(metaclass=SingletonMeta):
                         self._config_cache[data_id] = new_config
             except Exception as e:
                 SYLogger.error(f"nacos:配置监视线程异常: {str(e)}")
-            self._shutdown_event.wait(check_interval)  # 检查间隔
+            self._shutdown_event.wait(check_interval)
 
     def discover_services(self, service_name: str, group: str = "DEFAULT_GROUP", version: str = None) -> List[Dict]:
         """发现服务实例列表 (与Java格式兼容)"""
